@@ -22,12 +22,18 @@
 
 // Qt
 #include <QtCore/QFileInfo>
+#include <QtCore/QStandardPaths>
 #include <QStandardItem>
 
 // KDE
 #include <KKeySequenceWidget>
-#include <KStandardDirs>
-#include <KDebug>
+#include <QDebug>
+#include <KLocalizedString>
+#include <KIconLoader>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 // Konsole
 #include "EditProfileDialog.h"
@@ -41,17 +47,22 @@
 using namespace Konsole;
 
 ManageProfilesDialog::ManageProfilesDialog(QWidget* aParent)
-    : KDialog(aParent)
+    : QDialog(aParent)
     , _sessionModel(new QStandardItemModel(this))
 {
-    setCaption(i18nc("@title:window", "Manage Profiles"));
-    setButtons(KDialog::Close);
-
-    connect(this, SIGNAL(finished()),
-            ProfileManager::instance(), SLOT(saveSettings()));
+    setWindowTitle(i18nc("@title:window", "Manage Profiles"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &ManageProfilesDialog::slotAccepted);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &ManageProfilesDialog::reject);
+    mainLayout->addWidget(buttonBox);
 
+    
     _ui = new Ui::ManageProfilesDialog();
-    _ui->setupUi(mainWidget());
+    _ui->setupUi(mainWidget);
 
     // hide vertical header
     _ui->sessionTable->verticalHeader()->hide();
@@ -65,15 +76,10 @@ ManageProfilesDialog::ManageProfilesDialog(QWidget* aParent)
     populateTable();
 
     // listen for changes to profiles
-    connect(ProfileManager::instance(), SIGNAL(profileAdded(Profile::Ptr)), this,
-            SLOT(addItems(Profile::Ptr)));
-    connect(ProfileManager::instance(), SIGNAL(profileRemoved(Profile::Ptr)), this,
-            SLOT(removeItems(Profile::Ptr)));
-    connect(ProfileManager::instance(), SIGNAL(profileChanged(Profile::Ptr)), this,
-            SLOT(updateItems(Profile::Ptr)));
-    connect(ProfileManager::instance() ,
-            SIGNAL(favoriteStatusChanged(Profile::Ptr,bool)), this,
-            SLOT(updateFavoriteStatus(Profile::Ptr,bool)));
+    connect(ProfileManager::instance(), &Konsole::ProfileManager::profileAdded, this, &Konsole::ManageProfilesDialog::addItems);
+    connect(ProfileManager::instance(), &Konsole::ProfileManager::profileRemoved, this, &Konsole::ManageProfilesDialog::removeItems);
+    connect(ProfileManager::instance(), &Konsole::ProfileManager::profileChanged, this, &Konsole::ManageProfilesDialog::updateItems);
+    connect(ProfileManager::instance() , &Konsole::ProfileManager::favoriteStatusChanged, this, &Konsole::ManageProfilesDialog::updateFavoriteStatus);
 
     // resize the session table to the full width of the table
     _ui->sessionTable->horizontalHeader()->setHighlightSections(false);
@@ -86,10 +92,10 @@ ManageProfilesDialog::ManageProfilesDialog(QWidget* aParent)
                                       _ui->sessionTable->columnWidth(ShortcutColumn) + 100);
 
     // setup buttons
-    connect(_ui->newProfileButton, SIGNAL(clicked()), this, SLOT(createProfile()));
-    connect(_ui->editProfileButton, SIGNAL(clicked()), this, SLOT(editSelected()));
-    connect(_ui->deleteProfileButton, SIGNAL(clicked()), this, SLOT(deleteSelected()));
-    connect(_ui->setAsDefaultButton, SIGNAL(clicked()), this, SLOT(setSelectedAsDefault()));
+    connect(_ui->newProfileButton, &QPushButton::clicked, this, &Konsole::ManageProfilesDialog::createProfile);
+    connect(_ui->editProfileButton, &QPushButton::clicked, this, &Konsole::ManageProfilesDialog::editSelected);
+    connect(_ui->deleteProfileButton, &QPushButton::clicked, this, &Konsole::ManageProfilesDialog::deleteSelected);
+    connect(_ui->setAsDefaultButton, &QPushButton::clicked, this, &Konsole::ManageProfilesDialog::setSelectedAsDefault);
 }
 
 void ManageProfilesDialog::showEvent(QShowEvent*)
@@ -118,6 +124,12 @@ ManageProfilesDialog::~ManageProfilesDialog()
     delete _ui;
 }
 
+void ManageProfilesDialog::slotAccepted()
+{
+    ProfileManager::instance()->saveSettings();
+    deleteLater();
+}
+
 void ManageProfilesDialog::itemDataChanged(QStandardItem* item)
 {
     if (item->column() == ShortcutColumn) {
@@ -176,16 +188,16 @@ void ManageProfilesDialog::updateItemsForProfile(const Profile::Ptr profile, QLi
     // Profile Name
     items[ProfileNameColumn]->setText(profile->name());
     if (!profile->icon().isEmpty())
-        items[ProfileNameColumn]->setIcon(KIcon(profile->icon()));
+        items[ProfileNameColumn]->setIcon(QIcon::fromTheme(profile->icon()));
     items[ProfileNameColumn]->setData(QVariant::fromValue(profile), ProfileKeyRole);
     items[ProfileNameColumn]->setToolTip(i18nc("@info:tooltip", "Click to rename profile"));
 
     // Favorite Status
     const bool isFavorite = ProfileManager::instance()->findFavorites().contains(profile);
     if (isFavorite)
-        items[FavoriteStatusColumn]->setData(KIcon("dialog-ok-apply"), Qt::DecorationRole);
+        items[FavoriteStatusColumn]->setData(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")), Qt::DecorationRole);
     else
-        items[FavoriteStatusColumn]->setData(KIcon(), Qt::DecorationRole);
+        items[FavoriteStatusColumn]->setData(QIcon(), Qt::DecorationRole);
     items[FavoriteStatusColumn]->setData(QVariant::fromValue(profile), ProfileKeyRole);
     items[FavoriteStatusColumn]->setToolTip(i18nc("@info:tooltip", "Click to toggle status"));
 
@@ -227,17 +239,14 @@ void ManageProfilesDialog::populateTable()
     }
     updateDefaultItem();
 
-    connect(_sessionModel, SIGNAL(itemChanged(QStandardItem*)), this,
-            SLOT(itemDataChanged(QStandardItem*)));
+    connect(_sessionModel, &QStandardItemModel::itemChanged, this, &Konsole::ManageProfilesDialog::itemDataChanged);
 
     // listen for changes in the table selection and update the state of the form's buttons
     // accordingly.
     //
     // it appears that the selection model is changed when the model itself is replaced,
     // so the signals need to be reconnected each time the model is updated.
-    connect(_ui->sessionTable->selectionModel(),
-            SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this,
-            SLOT(tableSelectionChanged(QItemSelection)));
+    connect(_ui->sessionTable->selectionModel(), &QItemSelectionModel::selectionChanged, this, &Konsole::ManageProfilesDialog::tableSelectionChanged);
 
     _ui->sessionTable->selectRow(0);
 }
@@ -253,11 +262,12 @@ void ManageProfilesDialog::updateDefaultItem()
         bool isDefault = (defaultProfile == item->data().value<Profile::Ptr>());
 
         if (isDefault && !itemFont.bold()) {
-            item->setIcon(KIcon(defaultProfile->icon(), 0, QStringList("emblem-favorite")));
+            QIcon icon(KIconLoader::global()->loadIcon(defaultProfile->icon(), KIconLoader::Small, 0, KIconLoader::DefaultState, QStringList("emblem-favorite")));
+            item->setIcon(icon);
             itemFont.setBold(true);
             item->setFont(itemFont);
         } else if (!isDefault && itemFont.bold()) {
-            item->setIcon(KIcon(defaultProfile->icon()));
+            item->setIcon(QIcon(defaultProfile->icon()));
             itemFont.setBold(false);
             item->setFont(itemFont);
         }
@@ -403,7 +413,7 @@ Profile::Ptr ManageProfilesDialog::currentProfile() const
 }
 bool ManageProfilesDialog::isProfileDeletable(Profile::Ptr profile) const
 {
-    static const QString systemDataLocation = KStandardDirs::installPath("data") + "konsole/";
+    static const QString systemDataLocation = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).last() + QStringLiteral("konsole/");
 
     if (profile) {
         QFileInfo fileInfo(profile->path());
@@ -433,7 +443,7 @@ void ManageProfilesDialog::updateFavoriteStatus(Profile::Ptr profile, bool favor
     for (int i = 0; i < rowCount; i++) {
         QModelIndex index = _sessionModel->index(i, FavoriteStatusColumn);
         if (index.data(ProfileKeyRole).value<Profile::Ptr>() == profile) {
-            const KIcon icon = favorite ? KIcon("dialog-ok-apply") : KIcon();
+            const QIcon icon = favorite ? QIcon::fromTheme(QStringLiteral("dialog-ok-apply")) : QIcon();
             _sessionModel->setData(index, icon, Qt::DecorationRole);
         }
     }
@@ -496,7 +506,7 @@ ShortcutItemDelegate::ShortcutItemDelegate(QObject* aParent)
 void ShortcutItemDelegate::editorModified(const QKeySequence& keys)
 {
     Q_UNUSED(keys);
-    //kDebug() << keys.toString();
+    ////qDebug() << keys.toString();
 
     KKeySequenceWidget* editor = qobject_cast<KKeySequenceWidget*>(sender());
     Q_ASSERT(editor);
@@ -527,7 +537,7 @@ QWidget* ShortcutItemDelegate::createEditor(QWidget* aParent, const QStyleOption
     editor->setModifierlessAllowed(false);
     QString shortcutString = index.data(Qt::DisplayRole).toString();
     editor->setKeySequence(QKeySequence::fromString(shortcutString));
-    connect(editor, SIGNAL(keySequenceChanged(QKeySequence)), this, SLOT(editorModified(QKeySequence)));
+    connect(editor, &KKeySequenceWidget::keySequenceChanged, this, &Konsole::ShortcutItemDelegate::editorModified);
     editor->captureKeySequence();
     return editor;
 }
@@ -540,4 +550,3 @@ void ShortcutItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem&
         QStyledItemDelegate::paint(painter, option, index);
 }
 
-#include "ManageProfilesDialog.moc"
