@@ -28,8 +28,6 @@
 // KDE
 #include <KConfig>
 #include <KConfigGroup>
-#include <KGlobal>
-#include <KStandardDirs>
 
 // Konsole
 #include "ShellCommand.h"
@@ -42,8 +40,8 @@ static const char GENERAL_GROUP[]     = "General";
 QString KDE4ProfileWriter::getPath(const Profile::Ptr profile)
 {
     // both location have trailing slash
-    static const QString localDataLocation = KGlobal::dirs()->saveLocation("data", "konsole/");
-    static const QString systemDataLocation = KStandardDirs::installPath("data") + "konsole/";
+    static const QString localDataLocation = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/konsole/");
+    static const QString systemDataLocation = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).last() + QStringLiteral("konsole/");
 
     const QString candidateLocalPath = localDataLocation + profile->untranslatedName() + ".profile";
     QString newPath;
