@@ -28,7 +28,7 @@
 
 // Konsole
 #include "Character.h"
-#include "konsole_export.h"
+#include "konsoleprivate_export.h"
 #include "ScreenWindow.h"
 #include "ColorScheme.h"
 #include "Enumeration.h"
@@ -294,7 +294,6 @@ public:
     }
 
     void setSize(int columns, int lines);
-    void setFixedSize(int columns, int lines);
 
     // reimplemented
     QSize sizeHint() const;
@@ -450,6 +449,9 @@ public:
     /** Returns the terminal screen section which is displayed in this widget.  See setScreenWindow() */
     ScreenWindow* screenWindow() const;
 
+    // Select the current line.
+    void selectCurrentLine();
+
     void printContent(QPainter& painter, bool friendly);
 
 public slots:
@@ -534,6 +536,9 @@ public slots:
     /** See setUsesMouse() */
     bool usesMouse() const;
 
+    void setBracketedPasteMode(bool bracketedPasteMode);
+    bool bracketedPasteMode() const;
+
     /**
      * Shows a notification that a bell event has occurred in the terminal.
      * TODO: More documentation here
@@ -605,7 +610,7 @@ signals:
      */
     void overrideShortcutCheck(QKeyEvent* keyEvent, bool& override);
 
-    void sendStringToEmu(const char*);
+    void sendStringToEmu(const QByteArray& local8BitString);
 
 protected:
     virtual bool event(QEvent* event);
@@ -655,6 +660,7 @@ protected:
     void clearImage();
 
     void mouseTripleClickEvent(QMouseEvent* event);
+    void selectLine(QPoint pos, bool entireLine);
 
     // reimplemented
     virtual void inputMethodEvent(QInputMethodEvent* event);
@@ -680,6 +686,8 @@ private slots:
 
     void dropMenuCdActionTriggered();
 
+    void dismissOutputSuspendedMessage();
+
 private:
     // -- Drawing helpers --
 
@@ -765,6 +773,8 @@ private:
 
     QPoint findLineStart(const QPoint &pnt);
     QPoint findLineEnd(const QPoint &pnt);
+    QPoint findWordStart(const QPoint &pnt);
+    QPoint findWordEnd(const QPoint &pnt);
 
     // the window onto the terminal screen which this display
     // is currently showing.
@@ -808,6 +818,7 @@ private:
     bool _showTerminalSizeHint;
     bool _bidiEnabled;
     bool _mouseMarks;
+    bool _bracketedPasteMode;
 
     QPoint  _iPntSel; // initial selection point
     QPoint  _pntSel; // current selection point
@@ -837,7 +848,6 @@ private:
 
     bool _underlineLinks;     // Underline URL and hosts on mouse hover
     bool _openLinksByDirectClick;     // Open URL and hosts by single mouse click
-    bool _isFixedSize; // columns/lines are locked.
 
     bool _ctrlRequiredForDrag; // require Ctrl key for drag selected text
 
@@ -897,6 +907,8 @@ private:
     int _margin;      // the contents margin
     bool _centerContents;   // center the contents between margins
 
+    qreal _opacity;
+
     friend class TerminalDisplayAccessible;
 };
 
